==> gmic_2.3.1.tar.gz: gmic-2.3.1/gmic-qt/src/FilterParameters/ColorParameter.h <==
/** -*- mode: c++ ; c-basic-offset: 2 -*-
 *
 *  @file ColorParameter.h
 *
 *  Copyright 2017 Sebastien Fourey
 *
 *  This file is part of G'MIC-Qt, a generic plug-in for raster graphics
 *  editors, offering hundreds of filters thanks to the underlying G'MIC
 *  image processing framework.
 *
 *  gmic_qt is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  gmic_qt is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#ifndef _GMIC_QT_COLORPARAMETER_H_
#define _GMIC_QT_COLORPARAMETER_H_

#include <QColor>
#include <QColorDialog>
#include <QPixmap>
#include <QString>
#include "AbstractParameter.h"
class QSpinBox;
class QSlider;
class QLabel;
class QPushButton;

class ColorParameter : public AbstractParameter {
  Q_OBJECT
public:
  ColorParameter(QObject * parent = 0);
  ~ColorParameter();
  void addTo(QWidget *, int row) override;
  void addToKeypointList(KeypointList &) const override;
  void extractPositionFromKeypointList(KeypointList &) override;
  QString textValue() const override;
  void setValue(const QString & value) override;
  void reset() override;
  bool initFromText(const char * text, int & textLength) override;
public slots:
  void onButtonPressed();

private:
  void updateButtonColor();
  QString _name;
  QColor _default;
  QColor _value;
  bool _alphaChannel;
  QLabel * _label;
  QPushButton * _button;
  QPixmap _pixmap;
  QColorDialog * _dialog;
};

#endif // _GMIC_QT_COLORPARAMETER_H_

==> gmic_2.8.0.tar.gz: gmic-2.8.0/gmic-qt/src/FilterParameters/ColorParameter.h <==
/** -*- mode: c++ ; c-basic-offset: 2 -*-
 *
 *  @file ColorParameter.h
 *
 *  Copyright 2017 Sebastien Fourey
 *
 *  This file is part of G'MIC-Qt, a generic plug-in for raster graphics
 *  editors, offering hundreds of filters thanks to the underlying G'MIC
 *  image processing framework.
 *
 *  gmic_qt is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  gmic_qt is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#ifndef GMIC_QT_COLORPARAMETER_H
#define GMIC_QT_COLORPARAMETER_H

#include <QColor>
#include <QColorDialog>
#include <QPixmap>
#include <QString>
#include "AbstractParameter.h"
class QSpinBox;
class QSlider;
class QLabel;
class QPushButton;

class ColorParameter : public AbstractParameter {
  Q_OBJECT
public:
  ColorParameter(QObject * parent = nullptr);
  ~ColorParameter();
  bool addTo(QWidget *, int row) override;
  QString textValue() const override;
  void setValue(const QString & value) override;
  void reset() override;
  bool initFromText(const char * text, int & textLength) override;
public slots:
  void onButtonPressed();

private:
  void updateButtonColor();
  QString _name;
  QColor _default;
  QColor _value;
  bool _alphaChannel;
  QLabel * _label;
  QPushButton * _button;
  QPixmap _pixmap;
  QColorDialog * _dialog;
};

#endif // GMIC_QT_COLORPARAMETER_H
